@@ -14,6 +14,7 @@ from urllib.parse import urlparse
 from tuxsuite.cli.build import handlers as build_handlers
 from tuxsuite.cli.test import handlers as test_handlers
 from tuxsuite.cli.plan import handlers as plan_handlers
+from tuxsuite.cli.utils import LIMIT
 
 
 from tuxsuite.utils import (
@@ -345,7 +346,9 @@ def common_options(required):
     ]
 
     options = [
-        option("--limit", default=30, help="Limit to LIMIT output. Used with [list]"),
+        option(
+            "--limit", default=LIMIT, help="Limit to LIMIT output. Used with [list]"
+        ),
         option(
             "--json",
             default=False,
@@ -508,7 +511,7 @@ def build(
     output_dir=None,
     no_wait=False,
     patch_series=None,
-    limit=30,
+    limit=LIMIT,
     json=False,
     action=None,
     **build_params,
@@ -517,7 +520,7 @@ def build(
 
     if action in BUILD_SUBCOMMANDS:
         cfg, options = tuxcli_load()
-        if limit != 30:
+        if limit != LIMIT:
             options.limit = limit
         if json:
             options.json = json
@@ -785,7 +788,7 @@ def test_options(required):
         ),
         option(
             "--limit",
-            default=30,
+            default=LIMIT,
             help="Limit to LIMIT output. Used with [list]",
         ),
         option(
@@ -843,13 +846,13 @@ def test(
     json_out,
     json,
     raw,
-    limit=30,
+    limit=LIMIT,
     action=None,
     **test_params,
 ):
     if action:
         cfg, options = tuxcli_load()
-        if limit != 30:
+        if limit != LIMIT:
             options.limit = limit
         if json:
             options.json = json
@@ -1003,7 +1006,7 @@ plan_description = (
 )
 @click.option(
     "--limit",
-    default=30,
+    default=LIMIT,
     help="Limit to LIMIT output. Used with [list]",
 )
 @click.option(
@@ -1026,13 +1029,13 @@ def plan(
     no_wait=False,
     json_out=None,
     json=False,
-    limit=30,
+    limit=LIMIT,
     action=None,
     **build_params,
 ):
     if action in ["list", "get"]:
         cfg, options = tuxcli_load()
-        if limit != 30:
+        if limit != LIMIT:
             options.limit = limit
         if json:
             options.json = json
