@@ -4,10 +4,11 @@ import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Test
 from tuxsuite.cli.requests import apiurl, get, post
-from tuxsuite.cli.utils import datediff
+from tuxsuite.cli.utils import LIMIT, datediff, fetch_next
 from tuxsuite.cli.yaml import yaml_load
 
 import json
+import sys
 import time
 
 
@@ -77,28 +78,37 @@ def handle_get(options, config):
 
 
 def handle_list(options, config):
-    ret = get(config, f"/v1/groups/{config.group}/projects/{config.project}/tests")
+    url = f"/v1/groups/{config.group}/projects/{config.project}/tests"
+    ret = get(config, url)
     if ret.status_code != 200:
         raise NotImplementedError()
 
     tests = [Test.new(**t) for t in ret.json()["results"][: options.limit]]
+    n_token = ret.json()["next"]
     if options.json:
         print(json.dumps([t.as_dict() for t in tests]))
     else:
-        previous_pt = None
-        for test in tests:
-            state = test.result if test.state == "finished" else test.state
-            state_msg = f"{colors.state(test.state, test.result)}{state}{colors.reset}"
-            tests = ",".join(test.tests)
-            pt = test.provisioning_time
-            if pt is None:
-                pt = "....-..-..T..:..:........."
-            pt = pt[:-7]
-            print(
-                f"{datediff(previous_pt, pt)} {test.uid} [{state_msg}] {tests}@{test.device} {test.kernel}"
-            )
+        while True:
+            previous_pt = None
+            for test in tests:
+                state = test.result if test.state == "finished" else test.state
+                state_msg = (
+                    f"{colors.state(test.state, test.result)}{state}{colors.reset}"
+                )
+                tests = ",".join(test.tests)
+                pt = test.provisioning_time
+                if pt is None:
+                    pt = "....-..-..T..:..:........."
+                pt = pt[:-7]
+                print(
+                    f"{datediff(previous_pt, pt)} {test.uid} [{state_msg}] {tests}@{test.device} {test.kernel}"
+                )
+
+                previous_pt = pt
+            if sys.stdout.isatty():
+                # fetch next list of tests
+                tests, n_token = fetch_next(Test, config, url, n_token, options.limit)
 
-            previous_pt = pt
     return 0
 
 
@@ -107,6 +117,7 @@ def handle_logs(options, config):
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}/logs/lava",
     )
+    print(ret)
     if ret.status_code != 200:
         raise NotImplementedError()
 
@@ -259,7 +270,7 @@ def setup_parser(parser):
     # "test list"
     t = parser.add_parser("list")
     t.add_argument("--json", action="store_true")
-    t.add_argument("--limit", type=int, default=30)
+    t.add_argument("--limit", type=int, default=LIMIT)
 
     # "test logs <uid>"
     t = parser.add_parser("logs")
